@@ -103,14 +103,14 @@ fn parse_ifdata_item(parser: &mut ParserState, context: &ParseContext, spec: &A2
         A2mlTypeSpec::Enum(enumspec) => {
             let pos = parser.get_current_line_offset();
             let enumitem = parser.get_identifier(context)?;
-            if let Some(_) = enumspec.get(&enumitem) {
+            if enumspec.get(&enumitem).is_some() {
                 GenericIfData::EnumItem(pos, enumitem)
             } else {
                 return Err(ParseError::InvalidEnumValue(context.clone(), enumitem));
             }
         }
         A2mlTypeSpec::Struct(structspec) => {
-            let mut structitems = Vec::new();
+            let mut structitems = Vec::with_capacity(structspec.len());
             let line = parser.get_current_line_offset();
             for itemspec in structspec {
                 structitems.push(parse_ifdata_item(parser, context, itemspec)?);
@@ -144,12 +144,13 @@ fn parse_ifdata_item(parser: &mut ParserState, context: &ParseContext, spec: &A2
 // parse_ifdata_taggedstruct()
 // parse all the tagged items of a TaggedStruct (TaggedUnions are not handled here because no loop is needed for those)
 fn parse_ifdata_taggedstruct(parser: &mut ParserState, context: &ParseContext, tsspec: &HashMap<String, A2mlTaggedTypeSpec>) -> Result<HashMap<String, Vec<GenericIfDataTaggedItem>>, ParseError> {
-    let mut result = HashMap::new();
+    let mut result = HashMap::<String, Vec<GenericIfDataTaggedItem>>::new();
     while let Some(taggeditem) = parse_ifdata_taggeditem(parser, context, tsspec)? {
-        if result.get(&taggeditem.tag).is_none() {
-            result.insert(taggeditem.tag.clone(), Vec::new());
+        if let Some(itemvec) = result.get_mut(&taggeditem.tag) {
+            itemvec.push(taggeditem);
+        } else {
+            result.insert(taggeditem.tag.clone(), vec![taggeditem]);
         }
-        result.get_mut(&taggeditem.tag.clone()).unwrap().push(taggeditem);
     }
 
     Ok(result)
@@ -249,8 +250,7 @@ pub(crate) fn parse_unknown_ifdata_start(parser: &mut ParserState, context: &Par
         let mut tuitem = HashMap::new();
         tuitem.insert(tag.to_string(), vec![taggeditem]);
 
-        let mut items: Vec<GenericIfData> = Vec::new();
-        items.push(GenericIfData::TaggedUnion(tuitem));
+        let items: Vec<GenericIfData> = vec![GenericIfData::TaggedUnion(tuitem)];
 
         Ok(GenericIfData::Block{
             incfile: parser.get_incfilename(context.fileid),
@@ -331,7 +331,7 @@ fn parse_unknown_taggedstruct(parser: &mut ParserState, context: &ParseContext)
     while let Ok(Some((token, is_block, start_offset))) = parser.get_next_tag(context) {
         let uid = parser.get_next_id();
         let tag = parser.get_token_text(token);
-        let newcontext = ParseContext::from_token(tag, &token, true);
+        let newcontext = ParseContext::from_token(tag, token, true);
         let result = parse_unknown_ifdata(parser, &newcontext, is_block)?;
 
         let end_offset = parser.get_current_line_offset();
